VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "ImageProcessing"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
' +-------------------------------- DISCLAIMER ---------------------------------+
' |                                                                             |
' | This application program is provided to you free of charge as an example.   |
' | Despite the considerable efforts of Euresys personnel to create a usable    |
' | example, you should not assume that this program is error-free or suitable  |
' | for any purpose whatsoever.                                                 |
' |                                                                             |
' | EURESYS does not give any representation, warranty or undertaking that this |
' | program is free of any defect or error or suitable for any purpose. EURESYS |
' | shall not be liable, in contract, in torts or otherwise, for any damages,   |
' | loss, costs, expenses or other claims for compensation, including those     |
' | asserted by third parties, arising out of or in connection with the use of  |
' | this program.                                                               |
' |                                                                             |
' +-----------------------------------------------------------------------------+

Option Explicit

Option Base 0

'WinAPI Declarations
Private Declare Function DrawText Lib "user32" Alias "DrawTextA" _
   (ByVal hdc As Long, ByVal lpStr As String, ByVal nCount As Long, _
   lpRect As RECT, ByVal wFormat As Long) As Long
   
Private Declare Function SetTextColor Lib "gdi32" (ByVal hdc As Long, _
ByVal crColor As Long) As Long
   

Private Const DT_SINGLELINE = &H20
Private Const DT_NOCLIP = &H100

 Private Type RECT
    Left As Long
    Top As Long
    Right As Long
    Bottom As Long
 End Type



'Source and temporary images
Private m_SrcImg As New EImageBW8
Private m_RotatedImg As New EImageBW8

' ROI for OCR Operation
Private m_Roi As New EROIBW8

' EasyOCR Object
Private m_Ocr As New EOCR

' ERectangleGauge Object to detect the device body
Private m_RectGauge As New ERectangleGauge

Private m_EasyImage As New EasyImage

    
' Recognized string
Private m_Str As String


Public Sub Initialize()

    On Error GoTo Failure
    
    Dim sPath As String
    
    sPath = Left(App.Path, InStrRev(App.Path, "\") - 6)
    
    ' Load the EasyOCR font file
    m_Ocr.Load sPath & "\Resources\font\OCR-B.ocr"
    m_Ocr.TextColor = EOCRColor_WhiteOnBlack
 
    ' Set the Rectangle Gauge Parameters
    m_RectGauge.Tolerance = 100
    m_RectGauge.SetCenterXY 296, 258
    m_RectGauge.SetSize 375, 300
    
    m_RectGauge.MinAmplitude = 3
    m_RectGauge.Threshold = 5
    m_RectGauge.Thickness = 3

    m_RectGauge.TransitionChoice = ETransitionChoice_NthFromBegin
    m_RectGauge.TransitionType = ETransitionType_Wb
    
    m_RectGauge.NumFilteringPasses = 5
    m_RectGauge.FilteringThreshold = 2.1
    m_RectGauge.SamplingStep = 10
    
   On Error GoTo 0
    Exit Sub
    
Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "Lot Mixing Online"
            
End Sub

Public Sub Inspect(Filename As String)

    On Error GoTo Failure
      
    Dim d_MeasuredRectangle As New ERectangle
      
    'Load the image for inspection
    m_SrcImg.Load Filename
    m_RotatedImg.SetSize m_SrcImg.Width, m_SrcImg.Height
    
   ' Detect the body edge with the ERectangleGauge tool
    m_RectGauge.Measure m_SrcImg
    Set d_MeasuredRectangle = m_RectGauge.MeasuredRectangle
    
   ' Rotate the image to prepare for OCR operation
    m_EasyImage.ScaleRotate m_SrcImg, d_MeasuredRectangle.centerX, d_MeasuredRectangle.centerY, m_RotatedImg.Width / 2, m_RotatedImg.Height / 2, 1#, 1#, d_MeasuredRectangle.angle, m_RotatedImg, 8
    
    ' Place the ROI for OCR operation
    m_Roi.Attach m_RotatedImg
    m_Roi.SetPlacement m_RotatedImg.Width / 2 - 175, m_RotatedImg.Height / 2 - 125, 350, 250

    ' OCR operation
    m_Str = m_Ocr.Recognize(m_Roi, 7, EOCRClass.EOCRClass_AllClasses)
 
    On Error GoTo 0
    Exit Sub
    
Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "Lot Mixing Online"

End Sub

Public Sub Draw(HDCContext As Long)

    On Error GoTo Failure

    Dim I As Integer

    If m_SrcImg.IsVoid Then Exit Sub

    ' Draw the source image
    m_SrcImg.Draw HDCContext
    
    ' Draw the device bounding box
    m_RectGauge.Draw HDCContext, EDrawingMode_Actual
    
    ' Draw the result string
    Dim MyRect As RECT

    MyRect.Left = 20
    MyRect.Top = 20

    SetTextColor HDCContext, &HFFFFFF
    DrawText HDCContext, m_Str, Len(m_Str), MyRect, DT_SINGLELINE Or DT_NOCLIP

   On Error GoTo 0
    Exit Sub

Failure:
    ' Display the error description
    MsgBox "Error: " & Err.Description, vbOKOnly, "Lot Mixing Online"

End Sub

