// +-------------------------------- DISCLAIMER ---------------------------------+
// |                                                                             |
// | This application program is provided to you free of charge as an example.   |
// | Despite the considerable efforts of Euresys personnel to create a usable    |
// | example, you should not assume that this program is error-free or suitable  |
// | for any purpose whatsoever.                                                 |
// |                                                                             |
// | EURESYS does not give any representation, warranty or undertaking that this |
// | program is free of any defect or error or suitable for any purpose. EURESYS |
// | shall not be liable, in contract, in torts or otherwise, for any damages,   |
// | loss, costs, expenses or other claims for compensation, including those     |
// | asserted by third parties, arising out of or in connection with the use of  |
// | this program.                                                               |
// |                                                                             |
// +-----------------------------------------------------------------------------+
//
// ImageProcessing.cpp: implementation of the ImageProcessing class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "LotMixingLearn.h"
#include "ImageProcessing.h"
#include "CharClassAndCode.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

using namespace Euresys::Open_eVision_1_2;


ImageProcessing::ImageProcessing()
{

}

ImageProcessing::~ImageProcessing()
{

}


void ImageProcessing::OnLButtonDblClk(UINT nFlags, CPoint point)
{

	try
	{
		/// Check if a pattern has been selected 
		if(!(m_Ocr.HitChars(point.x, point.y, m_n32Index)))
			return;


		CharClassAndCode* pDlg = new CharClassAndCode;

		if (pDlg->DoModal() != IDOK)
		{ 
			return;
		}
		else
		{
			/// Get parameters for learning
			pDlg->GetParameters(m_sChar, m_nRecoClasses);
			LearnPattern();
		}

		delete pDlg;
		pDlg= NULL;
		
	}
	catch(EException exc)
	{
		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);
	}

	

}

 void ImageProcessing::Initialize()
{

	try
	{

		/// Load the image featuring the characters 
		m_SrcImg.Load("..\\..\\Resources\\font\\OCR-B.bmp");

		/// Set the characters color
		m_Ocr.SetTextColor(EOCRColor_WhiteOnBlack);

		/// Build blobs
		m_Ocr.BuildObjects(&m_SrcImg); 


		/// Build chars
		m_Ocr.FindAllChars(&m_SrcImg);


 	}
	catch(EException exc)
	{
		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);
		EError err = exc.GetError();
	}

	
}

 void ImageProcessing::SaveFontFile(LPCTSTR _mFilename)
 {
	try
	{
		/// Save the font file
		m_Ocr.Save(_mFilename);
	}
	catch(EException exc)
	{
		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);
		EError err = exc.GetError();
	}

 }



void ImageProcessing::Draw(HDC _mContext)
{


	try
	{
		/// Exit if no image has been loaded
		if (m_SrcImg.IsVoid())
			return;

		/// Draw the source image
		m_SrcImg.Draw(_mContext);

		/// Draw the character bounding box
		m_Ocr.DrawChars(_mContext);


	}
	catch(EException exc)
	{
		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);
	}


}

void ImageProcessing::LearnPattern()
{

	try
	{
	  /// If a class or code  has not been specified, inform about it
	  /// and don't do anything.
	  if(m_nRecoClasses == 0 || m_sChar=="" )
	  {
		AfxMessageBox("It is mandatory to select a character class and code. \nThe character has not been added"
			" to the font. " , MB_OK | MB_APPLMODAL | MB_ICONSTOP);
		return;
	  }
	  	

	   /// Add the pattern to the font
		m_Ocr.LearnPattern(&m_SrcImg, m_n32Index, m_sChar[0], m_nRecoClasses);


 	}
	catch(EException exc)
	{
		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);
	}


}
