// +-------------------------------- DISCLAIMER ---------------------------------+
// |                                                                             |
// | This application program is provided to you free of charge as an example.   |
// | Despite the considerable efforts of Euresys personnel to create a usable    |
// | example, you should not assume that this program is error-free or suitable  |
// | for any purpose whatsoever.                                                 |
// |                                                                             |
// | EURESYS does not give any representation, warranty or undertaking that this |
// | program is free of any defect or error or suitable for any purpose. EURESYS |
// | shall not be liable, in contract, in torts or otherwise, for any damages,   |
// | loss, costs, expenses or other claims for compensation, including those     |
// | asserted by third parties, arising out of or in connection with the use of  |
// | this program.                                                               |
// |                                                                             |
// +-----------------------------------------------------------------------------+
//
// ImageProcessing.cpp: implementation of the ImageProcessing class.
//
//////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "LotMixingOnline.h"
#include "ImageProcessing.h"


#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

using namespace Euresys::Open_eVision_1_2;

ImageProcessing::ImageProcessing()
{

}

ImageProcessing::~ImageProcessing()
{

}

 void ImageProcessing::Initialize()
{

	try
	{

        /// Load the EasyOCR font file 
		m_Ocr.Load("..\\..\\Resources\\font\\OCR-B.ocr");
		m_Ocr.SetTextColor(EOCRColor_WhiteOnBlack);

		/// Setting the Rectangle Gauge Parameters
		m_RectGauge.SetTolerance(100.00f);
		m_RectGauge.SetCenterXY(296.00f,258.00f);
		m_RectGauge.SetSize(375,300);

		m_RectGauge.SetMinAmplitude(3);
		m_RectGauge.SetThreshold(5);
		m_RectGauge.SetThickness(3);

		m_RectGauge.SetTransitionChoice(ETransitionChoice_NthFromBegin);
		m_RectGauge.SetTransitionType(ETransitionType_Wb);
		
		m_RectGauge.SetNumFilteringPasses(5);
		m_RectGauge.SetFilteringThreshold(2.1f);	
		m_RectGauge.SetSamplingStep(10);
		

 	}
	catch(EException exc)
	{

		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);

	}

	
}


void ImageProcessing::Inspect(LPCTSTR _mFilename)
{
			
	ERectangle	d_MeasuredRectangle; // ERectangle instance

	try
	{
		/// Load the image for inspection
		m_SrcImg.Load(_mFilename);
		m_RotatedImg.SetSize(&m_SrcImg);		
		
		/// Detect Body edge with the ERectangleGauge tool
		m_RectGauge.Measure(&m_SrcImg);
		d_MeasuredRectangle = m_RectGauge.GetMeasuredRectangle();

		/// Rotate the image to prepare for OCR operation
		EasyImage::ScaleRotate(&m_SrcImg, d_MeasuredRectangle.GetCenterX(), d_MeasuredRectangle.GetCenterY(), static_cast<float>(m_RotatedImg.GetWidth()/2), static_cast<float>(m_RotatedImg.GetHeight()/2), 1.00f, 1.00f, d_MeasuredRectangle.GetAngle(), &m_RotatedImg, 8);
		
        /// Place ROI for OCR operation
		m_Roi.Attach(&m_RotatedImg);
		m_Roi.SetPlacement(m_RotatedImg.GetWidth()/2 - 175, m_RotatedImg.GetHeight()/2 - 125, 350, 250);

	    /// OCR operation	
		m_Str = m_Ocr.Recognize(&m_Roi,7, EOCRClass_AllClasses);


	}
	catch(EException exc)
	{

		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);

	}

}


void ImageProcessing::Draw(HDC _mContext)
{

	try
	{
		/// Exit if no image has been loaded
		if (m_SrcImg.IsVoid())
			return;

		/// Draw the source image
		m_SrcImg.Draw(_mContext);

		/// Draw the device bounding box
		m_RectGauge.Draw(_mContext, EDrawingMode_Actual);


		/// Draw the result string
		RECT dRect;

		dRect.top =20;
		dRect.left=20;
		dRect.right= 50;
		dRect.bottom= 50;

		::SetTextColor(_mContext, RGB(255,255,255));

		::SetBkMode(_mContext, TRANSPARENT);

		::DrawText(_mContext, m_Str.c_str(),m_Str.size(),  &dRect, DT_SINGLELINE | DT_NOCLIP);


	}
	catch(EException exc)
	{

		::MessageBox(NULL, exc.What().c_str(), "Error", MB_OK | MB_ICONERROR);

	}


}


